@@ -6,12 +6,6 @@ from traceback import format_exc
 
 from exonutils.webapp import BaseWebApp, BaseWebView
 
-try:
-    import colorama
-    colorama.init()
-except ImportError:
-    pass
-
 logging.basicConfig(
     level=logging.INFO, stream=sys.stdout,
     format='%(asctime)s %(levelname)-5.5s [%(name)s] %(message)s')
@@ -45,6 +39,14 @@ class HomeView(BaseWebView):
         return self.__class__.__name__
 
 
+class ExitView(BaseWebView):
+    routes = [('/exit', 'exit')]
+
+    def get(self, **kwargs):
+        self.webapp.stop()
+        return ''
+
+
 if __name__ == '__main__':
     log = logging.getLogger()
     log.name = 'main'
@@ -64,16 +66,12 @@ if __name__ == '__main__':
             'templates_auto_reload': bool(args.debug >= 3),
         }
         webapp = BaseWebApp(options=cfg, logger=log, debug=args.debug)
-        webapp.views = [IndexView, HomeView]
-
-        # adjust request logs
-        logging.getLogger('werkzeug').parent = webapp.reqlog
-
+        webapp.views = [
+            IndexView, HomeView,
+            ExitView,
+        ]
         webapp.initialize()
-        webapp.create_app().run(
-            host='0.0.0.0', port='8000',
-            debug=bool(args.debug >= 1),
-            use_reloader=bool(args.debug >= 3))
+        webapp.start('0.0.0.0', 8000)
 
     except Exception:
         log.fatal(format_exc())
